@@ -53,15 +53,16 @@ function(basis, model=NULL, type="overall", value=NULL, coef=NULL, vcov=NULL,
   if(!is.null(model)) {
     model.class <- class(model)
     coef <- getcoef(model,model.class)
-    ind <- grep(cond,names(coef))
-    coef <- coef[ind]
-    vcov <- getvcov(model,model.class)[ind,ind,drop=FALSE]
+    vcov <- getvcov(model, model.class)
+    indcoef <- grep(cond,names(coef))
+    indvcov <- grep(cond,rownames(vcov))
+    coef <- coef[indcoef]
+    vcov <- vcov[indvcov,indvcov,drop=FALSE]
     model.link <- getlink(model,model.class)
   } else model.class <- NA
 #
   # CHECK COEF AND VCOV
-  npar <- if(type=="gam") length(ind) else ncol(basis)
-  npar <- if(type=="gam") length(ind) else ncol(basis)
+  npar <- if(type=="gam") length(indcoef) else ncol(basis)
   if(length(coef)!=npar || length(coef)!=dim(vcov)[1] || any(is.na(coef)) ||
       any(is.na(vcov)))
     stop("coef/vcov do not consistent with basis matrix. See help(crossreduce)")
